==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/polymer/item/PolymerItemImpl.java <==
package cc.thonly.polymer.item;

import cc.thonly.reverie_dreams.item.base.IDanmakuItem;
import cc.thonly.reverie_dreams.item.prop.TenguShieldItem;
import eu.pb4.polymer.core.api.item.PolymerItem;
import eu.pb4.polymer.core.api.utils.PolymerClientDecoded;
import eu.pb4.polymer.core.api.utils.PolymerKeepModel;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1747;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1819;
import net.minecraft.class_2680;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_3965;
import net.minecraft.item.*;
import xyz.nucleoid.packettweaker.PacketContext;

public class PolymerItemImpl implements PolymerItem, PolymerClientDecoded, PolymerKeepModel {
    private final class_1792 item;

    public PolymerItemImpl(class_1792 item) {
        this.item = item;
    }

    @Override
    public class_1792 getPolymerItem(class_1799 itemStack, PacketContext packetContext) {
        if (this.item instanceof IDanmakuItem) {
            return class_1802.field_8810;
        }
        if (this.item instanceof TenguShieldItem) {
            return class_1802.field_47315;
        }
        return this.item instanceof class_1819 ? class_1802.field_8255 : class_1802.field_47315;
    }

    @Override
    public boolean isPolymerBlockInteraction(class_2680 state, class_3222 player, class_1268 hand, class_1799 stack, class_3218 world, class_3965 blockHitResult, class_1269 actionResult) {
        return actionResult.method_23665();
    }

    @Override
    public boolean isIgnoringBlockInteractionPlaySoundExceptedEntity(class_2680 state, class_3222 player, class_1268 hand, class_1799 stack, class_3218 world, class_3965 blockHitResult) {
        return this.item instanceof class_1747;
    }

//    @Override
//    public void modifyBasePolymerItemStack(ItemStack out, ItemStack stack, PacketContext context) {
//        out.set(DataComponentTypes.TOOLTIP_DISPLAY, out.getOrDefault(DataComponentTypes.TOOLTIP_DISPLAY, TooltipDisplayComponent.DEFAULT));
//    }

}

==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/polymer/item/PolymerItemImpl.java <==
package cc.thonly.polymer.item;

import cc.thonly.reverie_dreams.config.ReverieDreamsConfiguration;
import cc.thonly.reverie_dreams.item.base.IDanmakuItem;
import cc.thonly.reverie_dreams.item.prop.Knife;
import cc.thonly.reverie_dreams.item.prop.TenguShieldItem;
import cc.thonly.reverie_dreams.item.weapon.TrumpetGun;
import eu.pb4.polymer.core.api.item.PolymerItem;
import eu.pb4.polymer.core.api.utils.PolymerClientDecoded;
import eu.pb4.polymer.core.api.utils.PolymerKeepModel;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1747;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1819;
import net.minecraft.class_2680;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_3965;
import xyz.nucleoid.packettweaker.PacketContext;

public class PolymerItemImpl implements PolymerItem, PolymerClientDecoded, PolymerKeepModel {
    private final class_1792 item;

    public PolymerItemImpl(class_1792 item) {
        this.item = item;
    }

    @Override
    public class_1792 getPolymerItem(class_1799 itemStack, PacketContext packetContext) {
        if (this.item instanceof TrumpetGun || this.item instanceof Knife) {
            return class_1802.field_47315;
        }
        if (this.item instanceof IDanmakuItem && ReverieDreamsConfiguration.ENABLE_DANMAKU_GLOW) {
            return class_1802.field_8810;
        }
        if (this.item instanceof TenguShieldItem) {
            return class_1802.field_47315;
        }
        return this.item instanceof class_1819 ? class_1802.field_8255 : class_1802.field_47315;
    }

    @Override
    public boolean isPolymerBlockInteraction(class_2680 state, class_3222 player, class_1268 hand, class_1799 stack, class_3218 world, class_3965 blockHitResult, class_1269 actionResult) {
        return actionResult.method_23665();
    }

    @Override
    public boolean isIgnoringBlockInteractionPlaySoundExceptedEntity(class_2680 state, class_3222 player, class_1268 hand, class_1799 stack, class_3218 world, class_3965 blockHitResult) {
        return this.item instanceof class_1747;
    }

//    @Override
//    public void modifyBasePolymerItemStack(ItemStack out, ItemStack stack, PacketContext context) {
//        out.set(DataComponentTypes.TOOLTIP_DISPLAY, out.getOrDefault(DataComponentTypes.TOOLTIP_DISPLAY, TooltipDisplayComponent.DEFAULT));
//    }

}
